from chucknorris import pronoun
from chucknorris import quips

def setup_module(module):
	config = {
		'female nicks': [
			'tracy',
		],
	}
	pronoun.load_nicks(config)

def test_pronounify():
	assert pronoun.nick_gender('tracy') == 'female'
	assert pronoun.pronounify('James is {his} own best friend', 'James',
		'tracy') == 'tracy is her own best friend'

def test_quips():
	assert 'tracy' in quips.random('tracy')
	assert 'his' not in quips.random('tracy')



from __future__ import absolute_import

import pmxbot
from pmxbot.core import command
from pmxbot.karma import Karma

from . import quips
from . import pronoun

@command('norris')
def norrisquote(client, event, channel, nick, rest):
    'Chuck Norris has a website dedicated to pmxbot facts.'
    if rest:
        rest = rest.strip()
        Karma.store.change(rest, 2)
        rcpt = rest
    else:
        rcpt = channel
    return quips.random(rcpt)

def init():
    pronoun.load_nicks(pmxbot.config)



import random as _random

import pkg_resources

from . import pronoun

_quips = [quip.rstrip().decode('utf-8') for quip in
    pkg_resources.resource_stream('chucknorris', 'quips.txt')
    if quip.rstrip()]

def random(name=None):
    return pronoun.pronounify(_random.choice(_quips), 'Chuck Norris', name)



pronouns = dict(
    male = {
        'his': 'his',
        'he': 'he',
        'He': 'He',
        'His': 'His',
        'him': 'him',
    },
    female = {
        'his': 'her',
        'he': 'she',
        'He': 'She',
        'His': 'Her',
        'him': 'her',
    }
)

female_nicks = set()
male_nicks = set()
default_gender = 'male'

def load_nicks(config):
    female_nicks.update(config.get('female nicks', []))
    male_nicks.update(config.get('male nicks', []))
    globals().update(
        default_gender=config.get('default gender', default_gender))

def nick_gender(nick):
    """
    Return the gender of the nick.
    """
    # Split on pipe to account for kristi|lunch
    nick = nick.split('|')[0]
    # Strip off trailing underscores
    nick = nick.rstrip('_')
    nick = nick.lower()
    if nick in female_nicks:
        return 'female'
    if nick in male_nicks:
        return 'male'
    # default to male because there tends to be more of that going on
    return default_gender


def pronounify(sentence, orig_name, nick=None):
    """
    Replace 'his' and 'he' with 'her' and 'she' if nick is female.  Assume
    sentence uses string formatting like {his} and {he}.
    """
    gender = nick_gender(nick or '')
    if nick:
        sentence = sentence.replace(orig_name, nick)
    return sentence.format(**pronouns[gender])
